@@ -80,6 +80,22 @@ module Util
     end
   end
 
+  def self.build_jbbs_post_str(name, mail, body, board_id, thread_id, server_time)
+    str = ""
+
+    str += "submit=%8F%91%82%AB%8D%9E%82%DE"
+
+    str += "&BBS=" + board_id.split("/")[1]
+    str += "&KEY=" + thread_id
+    str += "&DIR=" + board_id.split("/")[0]
+    str += "&NAME=" + CGI.escape(NKF.nkf("-Wsx", name)) # UTF-8 -> SJIS with JISX0201
+    str += "&MAIL=" + CGI.escape(NKF.nkf("-Wsx", mail)) # UTF-8 -> SJIS with JISX0201
+    str += "&MESSAGE=" + CGI.escape(NKF.nkf("-Wsx", body)) # UTF-8 -> SJIS with JISX0201
+    str += "&TIME=" + server_time.to_i.to_s
+
+    str
+  end
+
   def self.build_post_str(name, mail, body, board_id, thread_id, server_time, session_id)
     str = ""
 
@@ -120,7 +136,14 @@ module Util
   end
 
   def self.dat_url_to_write_url(url)
-    "http://#{URI.parse(url).host}/test/bbs.cgi"
+    case self.board_type(url)
+    when TYPE_2CH, TYPE_MACHIBBS, TYPE_UNKNOWN
+      "http://#{URI.parse(url).host}/test/bbs.cgi"
+    when TYPE_JBBS
+      board_id = self.dat_url_to_board_id(url)
+      thread_id = self.dat_url_to_thread_id(url)
+      "http://#{URI.parse(url).host}/bbs/write.cgi/#{board_id}/#{thread_id}/"
+    end
   end
 
   def self.dat_url_to_board_url(url)
@@ -128,10 +151,19 @@ module Util
     "http://#{URI.parse(url).host}/#{board_id}/"
   end
 
+  # http://jbbs.livedoor.jp/bbs/rawmode.cgi/computer/18420/1103791337/
+  # -> http://jbbs.livedoor.jp/bbs/read.cgi/computer/18420/1103791337/
   def self.dat_url_to_thread_url(url)
-    board_id = self.dat_url_to_board_id(url)
-    thread_id = self.dat_url_to_thread_id(url)
-    "http://#{URI.parse(url).host}/test/read.cgi/#{board_id}/#{thread_id}/"
+    case self.board_type(url)
+    when TYPE_2CH, TYPE_MACHIBBS, TYPE_UNKNOWN
+      board_id = self.dat_url_to_board_id(url)
+      thread_id = self.dat_url_to_thread_id(url)
+      "http://#{URI.parse(url).host}/test/read.cgi/#{board_id}/#{thread_id}/"
+    when TYPE_JBBS
+      board_id = self.dat_url_to_board_id(url)
+      thread_id = self.dat_url_to_thread_id(url)
+      "http://#{URI.parse(url).host}/bbs/read.cgi/#{board_id}/#{thread_id}/"
+    end
   end
 
   def self.dat_url_to_index_path(dat_url)
@@ -184,7 +216,7 @@ module Util
       ret += char
       count += 1
     }
-    ret += "…"
+    ret += "…" if str.size != ret.size
     ret
   end
 
@@ -196,4 +228,11 @@ module Util
       NKF.nkf("-Ewx", raw_str) # EUC-JP -> UTF-8 with JISX0201
     end
   end
+
+  def self.server_time(dat_url)
+    index_path = dat_url_to_index_path(dat_url)
+
+    config = KDE::Config.new(index_path)
+    config.readEntry("Date")
+  end
 end
